@@ -135,6 +135,30 @@ void sig_int_readline(int signo)
     rl_reset_line_state();
     rl_crlf();
     rl_redisplay();
+/*
+  rl_completion_found_quote = 0;
+  rl_completion_quote_character = 0;
+    rl_free_line_state ();
+      //rl_echo_signal_char (signo);
+      rl_cleanup_after_signal ();
+      rl_reset_after_signal ();
+  //rl_point = cxt->save_point;
+  //rl_mark = cxt->save_mark;
+  rl_maybe_unsave_line ();
+  rl_clear_message ();
+
+  rl_restore_prompt ();
+  rl_ding ();
+  rl_clear_message ();
+//  _rl_reset_argument ();
+  rl_clear_pending_input ();
+  RL_UNSETSTATE (RL_STATE_MACRODEF);
+  while (rl_executing_macro)
+    _rl_pop_executing_macro ();
+
+  rl_last_func = (rl_command_func_t *)NULL;
+  longjmp (_rl_top_level, 1);
+  */
 }
 
 static int readline_signal()
@@ -302,6 +326,7 @@ int main(int argc, char* argv[])
             sWFd* pipeout = sWFd_new(STDOUT_FILENO);
             sRFd* pipein = sRFd_new(STDIN_FILENO);
             int rcode = saphire_load(file_name, pipeout, pipein, STDERR_FILENO);
+            saphire_sweep();
             sWFd_flash(pipeout);
             sWFd_delete(pipeout);
             sRFd_delete(pipein);
@@ -329,6 +354,7 @@ int main(int argc, char* argv[])
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         sRFd* pipein = sRFd_new(STDIN_FILENO);
         int rcode = saphire_shell(send_cmd + 1, "saphire -a", pipeout, pipein, STDERR_FILENO);
+        saphire_sweep();
         sWFd_flash(pipeout);
         sWFd_delete(pipeout);
         sRFd_delete(pipein);
@@ -420,6 +446,7 @@ int main(int argc, char* argv[])
             sWFd* pipeout = sWFd_new(STDOUT_FILENO);
             sRFd* pipein = sRFd_new(STDIN_FILENO);
             int rcode = saphire_shell(buf, "saphire", pipeout, pipein, STDERR_FILENO);
+            saphire_sweep();
             sWFd_flash(pipeout);
             sWFd_delete(pipeout);
             sRFd_delete(pipein);
