@@ -51,6 +51,8 @@ enum eCommandKind {
     kMPrintw, 
     kSweep,
     kShow,
+    kYeild,
+//    kParse,
     kCommand 
 };
 
@@ -306,7 +308,7 @@ void sVar_save(sVar* self, int fd);
 
 typedef struct
 {
-    int mKind;   // 0: string 1: var 2: redirect 3: statments 4:var2 5: statments2
+    int mKind;   // 0: string 1: var 2: redirect 3: statments 4:var2 5: statments2 6: block
     void* mBody;
 } sArgTmp; // ѡǰŪ˻Ȥ
 
@@ -315,7 +317,7 @@ void sArgTmp_delete(sArgTmp* arg);
 
 typedef struct
 {
-    int mKind; // 0:string 1: var 2: statments 3:var2 4: statments2
+    int mKind; // 0:string 1: var 2: statments 3:var2 4: statments2 5: block
     void* mBody;
 } sArg; // mArgs
 
@@ -461,7 +463,7 @@ void sigchld_block(int block);
 ////////////////////////////////////////////////////////////
 /// from saphire_commands.c
 ////////////////////////////////////////////////////////////
-int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, sWFd* nextout, sRFd* nextin, int nexterr, int j, vector_obj* cprogs, char* title, BOOL input, BOOL* return_, char* sname, int line);
+int statment_tree_internal_commands(sCommand* command, int* rcode, vector_obj* argv, vector_obj* blocks, vector_obj* parent_blocks, sWFd* nextout, sRFd* nextin, int nexterr, int j, vector_obj* cprogs, char* title, BOOL input, BOOL* return_, char* sname, int line);
 BOOL vcat_expand_env(string_obj* pipeout, char* env, vector_obj* numbers,char* sname, int line);
 
 ////////////////////////////////////////////////////////////
