@@ -86,6 +86,8 @@ char* gStatmentKindStrs[kCommand+1] = {
     "mprintw",
     "sweep",
     "show",
+    "yeild",
+//    "parse",
     "command"
 };
 
@@ -1120,6 +1122,10 @@ void sArg_delete(sArg* self)
     case 4:
         sStatments_delete(self->mBody);
         break;
+
+    case 5:
+        sStatments_delete(self->mBody);
+        break;
     }
 
     FREE(self);
@@ -1165,6 +1171,10 @@ void sArg_save(sArg* self, int fd)
         case 4:
             sStatments_save(self->mBody, fd);
             break;
+
+        case 5:
+            sStatments_save(self->mBody, fd);
+            break;
     }
 }
 
@@ -1213,6 +1223,10 @@ sArg* sArg_load(int fd)
     case 4:
         self->mBody = sStatments_load(fd);
         break;
+
+    case 5:
+        self->mBody = sStatments_load(fd);
+        break;
     }
 
     return self;
@@ -1262,6 +1276,10 @@ void sArgTmp_delete(sArgTmp* self)
     case 5:
         if(self->mBody) sStatments_delete(self->mBody);
         break;
+
+    case 6:
+        if(self->mBody) sStatments_delete(self->mBody);
+        break;
     }
 
     FREE(self);
@@ -2453,7 +2471,7 @@ static void read_rc_obj_file(BOOL run_user_runtimescript)
         sWFd* pipeout = sWFd_new(STDOUT_FILENO);
         sRFd* pipein = sRFd_new(STDIN_FILENO);
         if(saphire_load_obj(rc_fname
-           , pipeout, pipein, STDERR_FILENO) < 0)
+           , pipeout, pipein, STDERR_FILENO, NULL) < 0)
         {
             fprintf(stderr, "%s", string_c_str(gErrMsg));
             exit(1);
@@ -2478,7 +2496,7 @@ static void read_rc_obj_file(BOOL run_user_runtimescript)
                 sWFd* pipeout = sWFd_new(STDOUT_FILENO);
                 sRFd* pipein = sRFd_new(STDIN_FILENO);
                 if(saphire_load_obj(user_rc_fname
-                    , pipeout, pipein, STDERR_FILENO) < 0)
+                    , pipeout, pipein, STDERR_FILENO, NULL) < 0)
                 {
                     fprintf(stderr, "%s", string_c_str(gErrMsg));
                     exit(1);
@@ -2523,7 +2541,7 @@ void saphire_init(enum eAppType app_type, BOOL job_control, enum eRuntimeScript
     gFileHandles = HASH_NEW(100);
     gReadBuffers = HASH_NEW(100);
 
-    setenv("SAPHIRE_VERSION", "1.0.0", 1);
+    setenv("SAPHIRE_VERSION", "1.0.3", 1);
     setenv("SAPHIRE_PROMPT", "> ", 1);
     setenv("SAPHIRE_DOCDIR", DOCDIR, 1);
     char* home = getenv("HOME");
